==> dde-control-center_5.4.23.orig.tar.xz: dde-control-center-5.4.23/translations/recovery_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="64"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Відновлюємо попередній стан системи. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="259"/>
        <source>Rollback failed.</source>
        <translation>Не вдалося відновити попередній стан.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="264"/>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="271"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Ви справді хочете повернутися до резервної копії deepin %1 від %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="274"/>
        <source>Cancel and Reboot</source>
        <translation>Скасувати і перезавантажитися</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="275"/>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
</TS>

==> dde-control-center_5.5.144.orig.tar.xz: dde-control-center-5.5.144/translations/recovery_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="65"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Відновлюємо попередній стан системи. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="266"/>
        <source>Rollback failed.</source>
        <translation>Не вдалося відновити попередній стан.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="271"/>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="280"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Ви справді хочете повернутися до резервної копії deepin %1 від %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="283"/>
        <source>Cancel and Reboot</source>
        <translation>Скасувати і перезавантажитися</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="284"/>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
</TS>
